==> 0.0.54.tar.gz: example/lib/Screen/DashBoardScreen.dart <==
import 'dart:convert';

import 'package:bui_component/CardComponent/cardComponent.dart';
import 'package:bui_component/DrawerComonent/kfDrawer.dart';
import 'package:bui_component/HomeScreenComponent.dart';
import 'package:example/Constants/AppColors.dart';
import 'package:example/Constants/AppStrings.dart';
import 'package:example/Constants/fontSize.dart';
import 'package:example/Constants/server_url.dart';
import 'package:example/Models/dash_board_detail_bean.dart';
import 'package:example/Screen/ThemePickerScreen.dart';
import 'package:example/Utils/class_builder.dart';
import 'package:example/network/api_service.dart';
import 'package:flutter/material.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:toast/toast.dart';

class DashBoardScreen extends KFDrawerContent {
  final Function() onMenuIconPressed;

  DashBoardScreen({this.onMenuIconPressed});

  @override
  _DashBoardScreenState createState() => _DashBoardScreenState();
}

class _DashBoardScreenState extends State<DashBoardScreen> {
  Color theme = AppColors.APP_COLOR_PRIMARY;
  Color secondaryBackgroundColor;

  List<PopupMenuItem> popUpMenu = new List();
  SharedPreferences prefs;

  num countValue = 2;

  num aspectWidth = 2;

  num aspectHeight = 1;

  bool isGridView = false;

  List<String> gridItems = [
    'Deals Created',
    'Won Deals',
    'Actual Revenue',
    'Expected Revenue',
    'Open Leads',
    'Conversion Rate',
    'Response Rate',
    'Open Task',
  ];

  DashBoardDetailBean dashBoardDetailsBeanResponse;

  bool isLoader;

  @override
  void initState() {
    ClassBuilder.registerClasses();
    colorCodePref();
    callDashBoardAPI();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: HomeScreenComponent(
        onMenuPressed: onMenuPressed,
        backgroundColor: theme,
        onMessageFunction: onMessageFunction,
        onNotificationFunction: onNotificationFunction,
        onSettingFunction: onSettingFunction,
        onPopUpMenuFunction: onPopUpMenuPressed,
        popUpMenu: popUpMenu,
        child: Stack(
          children: [
            Container(
              margin: EdgeInsets.only(top: 50),
              child: InkWell(
                onTap: () {
                  setState(() {
                    // widget.isGridView = !widget.isGridView;

                    changeOrderView();
                  });
                },
                child: Container(
                    alignment: Alignment.topRight,
                    padding: EdgeInsets.only(right: 20, top: 20),
                    child: Icon(
                      !isGridView ? Icons.list : Icons.grid_view,
                      color: secondaryBackgroundColor ?? theme,
                    )),
              ),
            ),
            Container(
              margin: EdgeInsets.only(top: 100),
              child: Column(children: [
                Expanded(
                  child: GridView.count(
                    crossAxisCount: countValue,
                    childAspectRatio: (aspectWidth / aspectHeight),


                    children: List.generate(gridItems.length, (index) {
                    return Center(
                      child: BUICard.dashBoardCardDeals(
                        cardType: CardType.cardDashBoardDeal,
                        cardSize: CardSize.large,
                        cardPrice: dashBoardDetailsBeanResponse.data.openTaksCurrent.toString(),

                        width: MediaQuery.of(context).size.width,
                        cardTitle: gridItems[index].toString(),
                        cardDate: dashBoardDetailsBeanResponse.data.chart[index].month,
                      ),
                    );
                  }),
                    /*gridItems
                        .map((data) => GestureDetector(
                              onTap: () {
                                getGridViewSelectedItem(context, data);
                              },
                              child: BUICard.dashBoardCardDeals(
                                cardType: CardType.cardDashBoardDeal,
                                width: MediaQuery.of(context).size.width * 0.2,
                                padding: 1,
                                elevation: 15,
                                cardSize: CardSize.small,
                                trandValue: true,
                                cardTextColor: theme,
                                cardTitle: data,
                                cardDate: ,
                              ),
                            ))
                        .toList(),*/
                  ),
                ),
              ]),
            ),
          ],
        ),
      ),
    );
  }

  Future<void> changeOrderView() async {
    setState(() {
      isGridView = !isGridView;
    });

    changeMode();
  }

  changeMode() {
    if (countValue == 2) {
      setState(() {
        countValue = 1;
        aspectWidth = 3;
        aspectHeight = 1;
      });
    } else {
      setState(() {
        countValue = 2;
        aspectWidth = 2;
        aspectHeight = 1;
      });
    }
  }

  getGridViewSelectedItem(BuildContext context, String gridItem) {
    showDialog(
      context: context,
      builder: (BuildContext context) {
        return AlertDialog(
          title: new Text(gridItem),
          actions: <Widget>[
            FlatButton(
              child: new Text("OK"),
              onPressed: () {
                Navigator.of(context).pop();
              },
            ),
          ],
        );
      },
    );
  }

  Future<void> onMenuPressed() async {
    setState(() {
      widget.onMenuPressed();

      widget.onMenuIconPressed();

      //   onMenuIconPressed();
    });
  }

  colorCodePref() async {
    prefs = await SharedPreferences.getInstance();
    String stringValue = prefs.getString(AppStrings.PRIMARY_THEME_COLOR);
    String secondaryColor = prefs.getString(AppStrings.SECONDARY_THEME_COLOR);

    if (stringValue != null) {
      int colorCodeInt = int.parse(stringValue);

      setState(() {
        theme = Color(colorCodeInt);
        this.mounted;
      });
    }

    popUpMenu = [
      PopupMenuItem(
        height: 30,
        value: 1,
        child: Row(
          children: [
            Padding(
              padding: const EdgeInsets.all(12.0),
              child: Icon(
                Icons.settings,
                color: theme ?? AppColors.APP_COLOR_BLACK,
              ),
            ),
            Text(
              AppStrings.SETTINGS,
              style: TextStyle(
                  fontWeight: FontWeight.bold,
                  fontSize: FontSize.FONT_14,
                  color: theme ?? Colors.black87),
            )
          ],
        ),
      ),
      PopupMenuItem(
        value: 2,
        child: Row(
          children: [
            Padding(
              padding: const EdgeInsets.all(12.0),
              child: Icon(
                Icons.notifications_active,
                color: theme ?? AppColors.APP_COLOR_BLACK,
              ),
            ),
            Text(
              AppStrings.NOTIFICATION,
              style: TextStyle(
                  fontWeight: FontWeight.bold,
                  fontSize: FontSize.FONT_14,
                  color: theme ?? Colors.black87),
            )
          ],
        ),
      ),
      PopupMenuItem(
        value: 3,
        child: Row(
          children: [
            Padding(
              padding: const EdgeInsets.all(12.0),
              child: Icon(
                Icons.messenger_rounded,
                color: theme ?? AppColors.APP_COLOR_BLACK,
              ),
            ),
            Text(
              AppStrings.MESSAGE,
              style: TextStyle(
                  fontWeight: FontWeight.bold,
                  fontSize: FontSize.FONT_14,
                  color: theme ?? Colors.black87),
            )
          ],
        ),
      ),
      PopupMenuItem(
        value: 4,
        child: Row(
          children: [
            Padding(
              padding: const EdgeInsets.all(12.0),
              child: Icon(
                Icons.color_lens_sharp,
                color: theme ?? AppColors.APP_COLOR_BLACK,
              ),
            ),
            Text(
              AppStrings.THEME,
              style: TextStyle(
                  fontWeight: FontWeight.bold,
                  fontSize: FontSize.FONT_14,
                  color: theme ?? Colors.black87),
            )
          ],
        ),
      ),
      PopupMenuItem(
        value: 5,
        child: Row(
          children: [
            Padding(
              padding: const EdgeInsets.all(12.0),
              child: Icon(
                Icons.feedback_rounded,
                color: theme ?? AppColors.APP_COLOR_BLACK,
              ),
            ),
            Text(
              AppStrings.FEED_BACK,
              style: TextStyle(
                  fontWeight: FontWeight.bold,
                  fontSize: FontSize.FONT_14,
                  color: theme ?? Colors.black87),
            )
          ],
        ),
      ),
    ];
    if (secondaryColor != null) {
      int colorCodeInt = int.parse(secondaryColor);
      setState(() {
        secondaryBackgroundColor = Color(colorCodeInt);
        this.mounted;
      });

      return stringValue;
    } else {
      secondaryBackgroundColor = AppColors.APP_COLOR_PRIMARY;
    }
  }

  void onBackPressed() {
    colorCodePref();
  }

  Future<void> onMessageFunction() async {
    setState(() {
      Toast.show("Message Pressed", context);
    });
  }

  Future<void> onFeedBackFunction() async {
    setState(() {});
  }

  Future<void> onSettingFunction() async {
    setState(() {
      Toast.show("Setting Pressed", context);
    });
  }

  Future<void> onNotificationFunction() async {
    setState(() {
      Toast.show("Notification Pressed", context);
    });
  }

  Future<void> onPopUpMenuPressed(int count) async {
    switch (count) {
      case 1:
        onSettingFunction();
        break;
      case 2:
        onNotificationFunction();
        break;
      case 3:
        onMessageFunction();
        break;
      case 4:
        onThemeFunction();
        break;
      case 5:
        onFeedBackFunction();
        break;

      default:
        break;
    }
  }

  Future<void> onThemeFunction() async {
    Navigator.push(
        context,
        MaterialPageRoute(
            builder: (BuildContext context) => ThemePickerScreen(
                  onBackPressed: onBackPressed,
                )));
  }

  Future<void> callDashBoardAPI() async {
    setState(() {
      isLoader = true;
    });
    String urlController = ServerUrl.CRM_DASHBOARD_URL;
    var objToSend = {
      "\"condition\"": [],
    };

    String jsonStr = objToSend.toString();

    String res = await APIClient.getInstance().callAPI(
        context, urlController, HTTPMethod.POST,
        isHeader: true, requestBody: jsonStr);
    Map map = jsonDecode(res);

    print("Map---->" + map.toString());
    DashBoardDetailBean dashBoardDetailBean = DashBoardDetailBean.fromJson(map);

    if (dashBoardDetailBean.status) {
      dashBoardDetailsBeanResponse = dashBoardDetailBean;
      setState(() {
        isLoader = false;
      });
    }

    Toast.show("API Call", context);
  }
}

==> 0.0.57.tar.gz: example/lib/Screen/DashBoardScreen.dart <==
import 'dart:convert';

import 'package:bui_component/CardComponent/cardComponent.dart';
import 'package:bui_component/DrawerComonent/kfDrawer.dart';
import 'package:bui_component/HomeScreenComponent.dart';
import 'package:example/Constants/AppColors.dart';
import 'package:example/Constants/AppStrings.dart';
import 'package:example/Constants/fontSize.dart';
import 'package:example/Constants/server_url.dart';
import 'package:example/Models/dash_board_detail_bean.dart';
import 'package:example/Screen/ThemePickerScreen.dart';
import 'package:example/Utils/class_builder.dart';
import 'package:example/network/api_service.dart';
import 'package:flutter/material.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:toast/toast.dart';

class DashBoardScreen extends KFDrawerContent {
  final Function() onMenuIconPressed;

  DashBoardScreen({this.onMenuIconPressed});

  @override
  _DashBoardScreenState createState() => _DashBoardScreenState();
}

class _DashBoardScreenState extends State<DashBoardScreen> {
  Color theme = AppColors.APP_COLOR_PRIMARY;
  Color secondaryBackgroundColor;

  List<PopupMenuItem> popUpMenu = new List();
  SharedPreferences prefs;

  num countValue = 2;

  num aspectWidth = 2;

  num aspectHeight = 1;

  bool isGridView = false;

  List<String> gridItems = [
    'Deals Created',
    'Won Deals',
    'Actual Revenue',
    'Expected Revenue',
    'Open Leads',
    'Conversion Rate',
    'Response Rate',
    'Open Task',
  ];

  DashBoardDetailBean dashBoardDetailsBeanResponse;

  bool isLoader;

  @override
  void initState() {
    ClassBuilder.registerClasses();
    colorCodePref();
    callDashBoardAPI();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: HomeScreenComponent(
        onMenuPressed: onMenuPressed,
        backgroundColor: theme,
        onMessageFunction: onMessageFunction,
        onNotificationFunction: onNotificationFunction,
        onSettingFunction: onSettingFunction,
        onPopUpMenuFunction: onPopUpMenuPressed,
        popUpMenu: popUpMenu,
        child:
        isLoader ? Container():

        Stack(
          children: [
            Container(
              margin: EdgeInsets.only(top: 50),
              child: InkWell(
                onTap: () {
                  setState(() {
                    // widget.isGridView = !widget.isGridView;

                    changeOrderView();
                  });
                },
                child: Container(
                    alignment: Alignment.topRight,
                    padding: EdgeInsets.only(right: 20, top: 20),
                    child: Icon(
                      !isGridView ? Icons.list : Icons.grid_view,
                      color: secondaryBackgroundColor ?? theme,
                    )),
              ),
            ),
            Container(
              margin: EdgeInsets.only(top: 100),
              child: Column(children: [
                Expanded(
                  child: GridView.count(
                    crossAxisCount: countValue,
                    childAspectRatio: (aspectWidth / aspectHeight),


                    children: List.generate(gridItems.length, (index) {
                    return Center(
                      child: BUICard.dashBoardCardDeals(
                        cardType: CardType.cardDashBoardDeal,
                        cardSize: CardSize.large,
                        cardPrice: dashBoardDetailsBeanResponse.data.openTaksCurrent.toString()!=null? dashBoardDetailsBeanResponse.data.openTaksCurrent.toString() : "",

                        width: MediaQuery.of(context).size.width,
                        cardTitle: gridItems[index].toString(),
                        cardDate: dashBoardDetailsBeanResponse.data.chart[index].month,
                      ),
                    );
                  }),
                    /*gridItems
                        .map((data) => GestureDetector(
                              onTap: () {
                                getGridViewSelectedItem(context, data);
                              },
                              child: BUICard.dashBoardCardDeals(
                                cardType: CardType.cardDashBoardDeal,
                                width: MediaQuery.of(context).size.width * 0.2,
                                padding: 1,
                                elevation: 15,
                                cardSize: CardSize.small,
                                trandValue: true,
                                cardTextColor: theme,
                                cardTitle: data,
                                cardDate: ,
                              ),
                            ))
                        .toList(),*/
                  ),
                ),
              ]),
            ),
          ],
        ),
      ),
    );
  }

  Future<void> changeOrderView() async {
    setState(() {
      isGridView = !isGridView;
    });

    changeMode();
  }

  changeMode() {
    if (countValue == 2) {
      setState(() {
        countValue = 1;
        aspectWidth = 3;
        aspectHeight = 1;
      });
    } else {
      setState(() {
        countValue = 2;
        aspectWidth = 2;
        aspectHeight = 1;
      });
    }
  }

  getGridViewSelectedItem(BuildContext context, String gridItem) {
    showDialog(
      context: context,
      builder: (BuildContext context) {
        return AlertDialog(
          title: new Text(gridItem),
          actions: <Widget>[
            FlatButton(
              child: new Text("OK"),
              onPressed: () {
                Navigator.of(context).pop();
              },
            ),
          ],
        );
      },
    );
  }

  Future<void> onMenuPressed() async {
    setState(() {
      widget.onMenuPressed();

      widget.onMenuIconPressed();

      //   onMenuIconPressed();
    });
  }

  colorCodePref() async {
    prefs = await SharedPreferences.getInstance();
    String stringValue = prefs.getString(AppStrings.PRIMARY_THEME_COLOR);
    String secondaryColor = prefs.getString(AppStrings.SECONDARY_THEME_COLOR);

    if (stringValue != null) {
      int colorCodeInt = int.parse(stringValue);

      setState(() {
        theme = Color(colorCodeInt);
        this.mounted;
      });
    }

    popUpMenu = [
      PopupMenuItem(
        height: 30,
        value: 1,
        child: Row(
          children: [
            Padding(
              padding: const EdgeInsets.all(12.0),
              child: Icon(
                Icons.settings,
                color: theme ?? AppColors.APP_COLOR_BLACK,
              ),
            ),
            Text(
              AppStrings.SETTINGS,
              style: TextStyle(
                  fontWeight: FontWeight.bold,
                  fontSize: FontSize.FONT_14,
                  color: theme ?? Colors.black87),
            )
          ],
        ),
      ),
      PopupMenuItem(
        value: 2,
        child: Row(
          children: [
            Padding(
              padding: const EdgeInsets.all(12.0),
              child: Icon(
                Icons.notifications_active,
                color: theme ?? AppColors.APP_COLOR_BLACK,
              ),
            ),
            Text(
              AppStrings.NOTIFICATION,
              style: TextStyle(
                  fontWeight: FontWeight.bold,
                  fontSize: FontSize.FONT_14,
                  color: theme ?? Colors.black87),
            )
          ],
        ),
      ),
      PopupMenuItem(
        value: 3,
        child: Row(
          children: [
            Padding(
              padding: const EdgeInsets.all(12.0),
              child: Icon(
                Icons.messenger_rounded,
                color: theme ?? AppColors.APP_COLOR_BLACK,
              ),
            ),
            Text(
              AppStrings.MESSAGE,
              style: TextStyle(
                  fontWeight: FontWeight.bold,
                  fontSize: FontSize.FONT_14,
                  color: theme ?? Colors.black87),
            )
          ],
        ),
      ),
      PopupMenuItem(
        value: 4,
        child: Row(
          children: [
            Padding(
              padding: const EdgeInsets.all(12.0),
              child: Icon(
                Icons.color_lens_sharp,
                color: theme ?? AppColors.APP_COLOR_BLACK,
              ),
            ),
            Text(
              AppStrings.THEME,
              style: TextStyle(
                  fontWeight: FontWeight.bold,
                  fontSize: FontSize.FONT_14,
                  color: theme ?? Colors.black87),
            )
          ],
        ),
      ),
      PopupMenuItem(
        value: 5,
        child: Row(
          children: [
            Padding(
              padding: const EdgeInsets.all(12.0),
              child: Icon(
                Icons.feedback_rounded,
                color: theme ?? AppColors.APP_COLOR_BLACK,
              ),
            ),
            Text(
              AppStrings.FEED_BACK,
              style: TextStyle(
                  fontWeight: FontWeight.bold,
                  fontSize: FontSize.FONT_14,
                  color: theme ?? Colors.black87),
            )
          ],
        ),
      ),
    ];
    if (secondaryColor != null) {
      int colorCodeInt = int.parse(secondaryColor);
      setState(() {
        secondaryBackgroundColor = Color(colorCodeInt);
        this.mounted;
      });

      return stringValue;
    } else {
      secondaryBackgroundColor = AppColors.APP_COLOR_PRIMARY;
    }
  }

  void onBackPressed() {
    colorCodePref();
  }

  Future<void> onMessageFunction() async {
    setState(() {
      Toast.show("Message Pressed", context);
    });
  }

  Future<void> onFeedBackFunction() async {
    setState(() {});
  }

  Future<void> onSettingFunction() async {
    setState(() {
      Toast.show("Setting Pressed", context);
    });
  }

  Future<void> onNotificationFunction() async {
    setState(() {
      Toast.show("Notification Pressed", context);
    });
  }

  Future<void> onPopUpMenuPressed(int count) async {
    switch (count) {
      case 1:
        onSettingFunction();
        break;
      case 2:
        onNotificationFunction();
        break;
      case 3:
        onMessageFunction();
        break;
      case 4:
        onThemeFunction();
        break;
      case 5:
        onFeedBackFunction();
        break;

      default:
        break;
    }
  }

  Future<void> onThemeFunction() async {
    Navigator.push(
        context,
        MaterialPageRoute(
            builder: (BuildContext context) => ThemePickerScreen(
                  onBackPressed: onBackPressed,
                )));
  }

  Future<void> callDashBoardAPI() async {
    setState(() {
      isLoader = true;
    });
    String urlController = ServerUrl.CRM_DASHBOARD_URL;
    var objToSend = {
      "\"condition\"": [],
    };

    String jsonStr = objToSend.toString();

    String res = await APIClient.getInstance().callAPI(
        context, urlController, HTTPMethod.POST,
        isHeader: true, requestBody: jsonStr);
    Map map = jsonDecode(res);

    print("Map---->" + map.toString());
    DashBoardDetailBean dashBoardDetailBean = DashBoardDetailBean.fromJson(map);

    if (dashBoardDetailBean.status) {
      dashBoardDetailsBeanResponse = dashBoardDetailBean;
      setState(() {
        isLoader = false;
      });
    }

    Toast.show("API Call", context);
  }
}
